function [data, auxData, metaData, txtData, weights] = mydata_Sterna_paradisaea
%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Charadriiformes'; 
metaData.family     = 'Laridae';
metaData.species    = 'Sternula_albifrons'; 
metaData.species_en = 'Little tern'; 

metaData.ecoCode.climate = {'C', 'D'};
metaData.ecoCode.ecozone = {'THp'};
metaData.ecoCode.habitat = {'0iFm', '0iMc'};
metaData.ecoCode.embryo  = {'Tnsfm'};
metaData.ecoCode.migrate = {'Ml'};
metaData.ecoCode.food    = {'biCvf'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(40.7); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2018 10 13];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.author_mod_1   = {'Bas Kooijman'};    
metaData.date_mod_1     = [2022 11 28];              
metaData.email_mod_1    = {'bas.kooijman@vu.nl'};            
metaData.address_mod_1  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'sta@akvaplan.niva.no'}; 
metaData.date_acc    = [2022 11 28]; 

%% set data
% zero-variate data

data.ab = 21;          units.ab = 'd';    label.ab = 'age at birth';             bibkey.ab = 'AnAge';   
  temp.ab = C2K(32);   units.temp.ab = 'K'; label.temp.ab = 'temperature';
data.tx = 19;          units.tx = 'd';    label.tx = 'time since birth at fledging'; bibkey.tx = 'PaivRamo2006';   
  temp.tx = C2K(40.7); units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tR = 730;        units.tR = 'd';    label.tR = 'time since birth at 1st brood';  bibkey.tR = 'AnAge';
  temp.tR = C2K(40.7); units.temp.tR = 'K'; label.temp.tR = 'temperature';
data.am = 23.9*365;      units.am = 'd';    label.am = 'life span';                bibkey.am = 'AnAge';   
  temp.am = C2K(40.7); units.temp.am = 'K'; label.temp.am = 'temperature'; 
  
data.Wwb = 6.5;       units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'PaivRamo2006';
data.Wwi = 45;        units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';     bibkey.Wwi = 'PaivRamo2006';
  comment.Wwi = 'AnAge: 31 g';

data.Ri  = 2/365;    units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';     bibkey.Ri  = 'AnAge';   
  temp.Ri = C2K(40.7); units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  
% uni-variate data
% t-W data
data.tW = [ ... % time since birth (d), wet weight (g)
0.283	6.526
0.765	6.523
1.342	7.352
1.727	7.627
2.305	8.873
2.738	9.426
3.411	11.227
3.700	11.502
4.228	13.582
4.660	14.968
5.333	16.491
5.718	17.738
6.247	18.985
6.679	20.648
7.304	22.033
7.640	23.558
8.266	24.248
8.600	27.024
9.227	26.464
9.658	29.239
10.237	29.235
10.668	31.593
11.246	32.283
11.726	34.224
12.208	34.221
12.641	35.190
13.219	35.325
13.699	36.850
14.229	37.679
14.662	37.954
15.191	39.617
15.673	39.197
16.202	40.304
16.635	40.718
17.213	41.131
17.550	41.823
18.274	40.707
18.754	42.509];
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(40.7);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW  = 'PaivRamo2006';

%% set weights for all real data
weights = setweights(data, []);
weights.tW = 5 * weights.tW;
weights.Wwi = 10 * weights.Wwi;
weights.Wwb = 3 * weights.Wwb;
weights.Ri = 3 * weights.Ri;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Discussion points
D1 = 'Body temperature is guessed';
D2 = 'Relative food intake reduced just after hatching';
D3 = 'mod_1: v is reduced';
metaData.discussion = struct('D1',D1, 'D2',D2, 'D3',D3);

%% Links
metaData.links.id_CoL = '52G25'; % Cat of Life
metaData.links.id_ITIS = '824126'; % ITIS
metaData.links.id_EoL = '45509317'; % Ency of Life
metaData.links.id_Wiki = 'Sternula_albifrons'; % Wikipedia
metaData.links.id_ADW = 'Sterna_albifrons'; % ADW
metaData.links.id_Taxo = '2682544'; % Taxonomicon
metaData.links.id_WoRMS = '567480'; % WoRMS
metaData.links.id_avibase = '17310BF0FE9BAC8A'; % avibase
metaData.links.id_birdlife = 'little-tern-sternula-albifrons'; % birdlife
metaData.links.id_AnAge = 'Sternula_albifrons'; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Sternula_albifrons}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Sternula_albifrons}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'PaivRamo2006'; type = 'Article'; bib = [ ... 
'author = {V. H. Paiva and J. A. Ramos and D. Machado and G. Penha-Lopes and M. F. Bouslama and N. Dias and S. Nielsen}, ' ... 
'year = {2006}, ' ...
'title = {Importance of marine prey to growth of estuarine tern chicks: evidence from an energetic balance model}, ' ...
'journal = {Ardea}, ' ...
'volume = {94}, ' ...
'pages = {241-255}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

